@@ -40,7 +40,7 @@ import org.apache.royale.compiler.clients.problems.ProblemQuery;
 import org.apache.royale.compiler.clients.problems.ProblemQueryProvider;
 import org.apache.royale.compiler.clients.problems.WorkspaceProblemFormatter;
 import org.apache.royale.compiler.codegen.js.IJSWriter;
-import org.apache.royale.compiler.codegen.js.goog.IJSGoogPublisher;
+import org.apache.royale.compiler.codegen.js.royale.IJSRoyalePublisher;
 import org.apache.royale.compiler.config.Configuration;
 import org.apache.royale.compiler.config.ConfigurationBuffer;
 import org.apache.royale.compiler.config.Configurator;
@@ -123,8 +123,6 @@ public class MXMLJSCRoyaleCordova implements JSCompilerEntryPoint, ProblemQueryP
         }
     }
 
-    public static MXMLJSC.JSOutputType jsOutputType;
-
     @Override
     public String getName()
     {
@@ -184,7 +182,7 @@ public class MXMLJSCRoyaleCordova implements JSCompilerEntryPoint, ProblemQueryP
     protected ITarget target;
     protected ITargetSettings targetSettings;
     protected IJSApplication jsTarget;
-    private IJSGoogPublisher jsPublisher;
+    private IJSRoyalePublisher jsPublisher;
     
     public MXMLJSCRoyaleCordova()
     {
@@ -402,7 +400,7 @@ public class MXMLJSCRoyaleCordova implements JSCompilerEntryPoint, ProblemQueryP
                 Set<String> closurePropNamesToKeep = new HashSet<String>();
                 //use a LinkedHashSet because the order of the exported names matters -JT
                 LinkedHashSet<String> closureSymbolNamesToExport = new LinkedHashSet<String>();
-                jsPublisher = (IJSGoogPublisher) project.getBackend().createPublisher(
+                jsPublisher = (IJSRoyalePublisher) project.getBackend().createPublisher(
                         project, errors, config);
 
                 File outputFolder = jsPublisher.getOutputFolder();
@@ -690,7 +688,17 @@ public class MXMLJSCRoyaleCordova implements JSCompilerEntryPoint, ProblemQueryP
 
         ITargetSettings settings = getTargetSettings();
         if (settings != null)
+        {
             project.setTargetSettings(settings);
+        }
+        else
+        {
+            // if getTargetSettings() returned null, then there will definitely
+            // be new config problems that weren't there after applyToProject()
+            // succeeded
+            problems.addAll(projectConfigurator.getConfigurationProblems());
+            return false;
+        }
 
         target = project.getBackend().createTarget(project,
                 getTargetSettings(), null);
